.. hpcmd documentation master file, created by
   sphinx-quickstart on Tue Jul 17 13:05:42 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to bioen's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Introduction
------------

TBD


Installation
------------

bioen is written in Python and is compatible with Python 2.7 (3.6 in
preparation). It is installed in the standard way using ``setup.py``.


Usage
-----

TBD

.. see redesign.rst for the optimize part

.. toctree::
   :maxdepth: 2

   fileio.rst


Source documentation
====================

The documentation linked below is generated automatically from the docstrings
present in the bioen source code.

.. toctree::
   :maxdepth: 2

   modules.rst


Copyright and License
=====================

Copyright 2018 Katrin Reichel, Jürgen Köfinger, Klaus Reuter, César Allande, Lukas S. Stelzl, Gerhard Hummer

License: GNU GPL version 3. See the files ``LICENSE.txt`` and ``COPYING`` for details.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
